import React from 'react';
import type { StatisticsData } from './statisticsRequests';
import GlassCard from '../../shared/GlassCard';

interface StatisticsGraphsProps {
  isLoading: boolean;
  error: string | null;
  statisticsData: StatisticsData | null;
}

const StatisticsGraphs: React.FC<StatisticsGraphsProps> = ({
  isLoading,
  error,
  statisticsData,
}) => {
  if (error) {
    return (
      <GlassCard className="flex items-center justify-center h-64">
        <div className="text-center">
          <div className="text-red-600 text-lg mb-2">⚠️ Erro</div>
          <p className="text-gray-700">{error}</p>
        </div>
      </GlassCard>
    );
  }

  if (isLoading) {
    return (
      <GlassCard className="flex items-center justify-center h-64">
        <div className="text-center">
          <div className="animate-spin w-8 h-8 border-2 border-blue-600 border-t-transparent rounded-full mx-auto mb-4"></div>
          <p className="text-gray-700">Carregando dados...</p>
        </div>
      </GlassCard>
    );
  }

  if (!statisticsData) {
    return (
      <GlassCard className="flex items-center justify-center h-64">
        <div className="text-center">
          <div className="text-gray-500 text-4xl mb-4">📊</div>
          <h3 className="text-gray-900 text-lg mb-2">Nenhum dado encontrado</h3>
          <p className="text-gray-700">
            Os dados estatísticos não puderam ser carregados
          </p>
        </div>
      </GlassCard>
    );
  }

  const renderDataTable = (title: string, data: any[], type: 'candidate' | 'party' | 'state' | 'enrichment') => {
    if (!data || data.length === 0) {
      return (
        <GlassCard>
          <div>
            <h3 className="text-lg font-semibold text-gray-900 mb-4">{title}</h3>
            <p className="text-gray-700">Nenhum dado disponível</p>
          </div>
        </GlassCard>
      );
    }

    if (type === 'enrichment') {
      const enrichmentData = data[0]; // Single enrichment response
      return (
        <GlassCard>
          <div>
            <h3 className="text-lg font-semibold text-gray-900 mb-4">{title}</h3>
            <div className="space-y-3">
              <div className="flex justify-between items-center">
                <span className="text-gray-600">Candidato:</span>
                <span className="text-gray-900 font-medium">{enrichmentData.nome}</span>
              </div>
              <div className="flex justify-between items-center">
                <span className="text-gray-600">Patrimônio Inicial (<span className="text-xs text-gray-500">{enrichmentData.anoInicial}</span>):</span>
                <span className="text-gray-900 font-medium">
                  R$ {enrichmentData.patrimonioInicial?.toLocaleString('pt-BR') || '0'}
                        
                </span>
              </div>
              <div className="flex justify-between items-center">
                <span className="text-gray-600">Patrimônio Final (<span className="text-xs text-gray-500">{enrichmentData.anoFinal}</span>):</span>
                <span className="text-gray-900 font-medium">
                  R$ {enrichmentData.patrimonioFinal?.toLocaleString('pt-BR') || '0'}
                </span>
              </div>
              <div className="border-t border-gray-200 pt-3">
                <div className="flex justify-between items-center">
                  <span className="text-gray-600">Enriquecimento:</span>
                  <span className={`font-bold text-lg ${
                    enrichmentData.enriquecimento >= 0 ? 'text-green-600' : 'text-red-600'
                  }`}>
                    {enrichmentData.enriquecimento >= 0 ? '+' : ''}
                    R$ {enrichmentData.enriquecimento?.toLocaleString('pt-BR') || '0'}
                  </span>
                </div>
              </div>
            </div>
          </div>
        </GlassCard>
      );
    }

    return (
      <GlassCard>
        <div>
          <h3 className="text-lg font-semibold text-gray-900 mb-4">{title}</h3>
          <div className="overflow-auto max-h-60 scrollbar-hide">
            <table className="w-full text-sm">
              <thead>
                <tr className="border-b border-gray-200">
                  {type === 'candidate' && (
                    <>
                      <th className="text-left py-2 text-gray-600 font-medium">Nome</th>
                    </>
                  )}
                  {type === 'party' && (
                    <th className="text-left py-2 text-gray-600 font-medium">Partido</th>
                  )}
                  {type === 'state' && (
                    <th className="text-left py-2 text-gray-600 font-medium">UF</th>
                  )}
                  <th className="text-left py-2 text-gray-600 font-medium">Ano</th>
                  <th className="text-right py-2 text-gray-600 font-medium">Valor</th>
                </tr>
              </thead>
              <tbody>
                {data.slice(0, 5).map((item, index) => (
                  <tr key={index} className="border-b border-gray-100 hover:bg-gray-50 transition-colors duration-150">
                    {type === 'candidate' && (
                      <>
                        <td className="py-3 text-gray-900">{item.nome || 'N/A'}</td>
                      </>
                    )}
                    {type === 'party' && (
                      <td className="py-3 text-gray-900">{item.sgpartido || 'N/A'}</td>
                    )}
                    {type === 'state' && (
                      <td className="py-3 text-gray-900">{item.siglaUf || 'N/A'}</td>
                    )}
                    <td className="py-3 text-gray-900">{item.ano || 'N/A'}</td>
                    <td className="py-3 text-right font-medium text-gray-900">
                      R$ {item.valor?.toLocaleString('pt-BR') || '0'}
                    </td>
                  </tr>
                ))}
              </tbody>
            </table>
          </div>
        </div>
      </GlassCard>
    );
  };

  return (
    <div className="">
      <div className="space-y-6">
        {/* First Row - Candidates */}
        <div className="grid grid-cols-1 lg:grid-cols-2 gap-6">
          {renderDataTable(
            'Candidatos com Maiores Bens',
            statisticsData.candidatesWithMostAssets,
            'candidate'
          )}
          {statisticsData.enrichmentData && renderDataTable(
            'Análise de Enriquecimento',
            statisticsData.enrichmentData,
            'enrichment'
          )}
        </div>

        {/* Second Row - Candidates Revenue & Expenses */}
        <div className="grid grid-cols-1 lg:grid-cols-2 gap-6">
          {renderDataTable(
            'Candidatos com Maiores Receitas',
            statisticsData.candidatesWithMostRevenue,
            'candidate'
          )}
          {renderDataTable(
            'Candidatos com Maiores Despesas',
            statisticsData.candidatesWithMostExpenses,
            'candidate'
          )}
        </div>

        {/* Third Row - Parties */}
        <div className="grid grid-cols-1 lg:grid-cols-3 gap-6">
          {renderDataTable(
            'Partidos com Maiores Bens',
            statisticsData.partiesWithMostAssets,
            'party'
          )}
          {renderDataTable(
            'Partidos com Maiores Despesas',
            statisticsData.partiesWithMostExpenses,
            'party'
          )}
          {renderDataTable(
            'Partidos com Maiores Receitas',
            statisticsData.partiesWithMostRevenue,
            'party'
          )}
        </div>

        {/* Fourth Row - States */}
        <div className="grid grid-cols-1 lg:grid-cols-3 gap-6">
          {renderDataTable(
            'UFs com Maiores Bens',
            statisticsData.statesWithMostAssets,
            'state'
          )}
          {renderDataTable(
            'UFs com Maiores Despesas',
            statisticsData.statesWithMostExpenses,
            'state'
          )}
          {renderDataTable(
            'UFs com Maiores Receitas',
            statisticsData.statesWithMostRevenue,
            'state'
          )}
        </div>
      </div>
    </div>
  );
};

export default StatisticsGraphs;
